﻿using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;
    
namespace Game2D
{
    class Sprite
    {
        // Поля
        public Texture2D spriteTexture;// Ссылка на объект рисунка
        public Vector2 spritePosition; // Позиция рисования
    
        int frameCount;     // Количество кадров последовательности
        double timeFrame;   // Время показа одного фрейма на экране (задержка)
        int frame;          // Номер показываемого фрейма
        double totalElapsed;// Время, прошедшее с начала показа текущего фрейма
        public Vector2 speedSprite = new Vector2(0, 6);// Скорость перемещения в pixels
    
        // Параметризованный конструктор
        public Sprite(int frameCount, int framesPerSec)
        {
            this.frameCount = frameCount;
            timeFrame = 1D / framesPerSec;
            frame = 0;
            totalElapsed = 0d;
        }
    
        // Если есть параметризованный конструктор, то
        // нужно явно определить конструктор по умолчанию
        public Sprite()
        {
        }
    
        // Переход к следующему фрейму по истечении системного времени
        public void UpdateFrame(double elapsed)
        {
            totalElapsed += elapsed;
            if (totalElapsed > timeFrame)
            {
                frame++;// Счетчик кадров
                frame = frame % (frameCount - 1);// Деление по модулю
                totalElapsed = 0D;// Текущее время показа нового фрейма
            }
        }
    
        // Рисование текущего спрайта последовательности
        public void DrawAnimationSprite(SpriteBatch spriteBatch)
        {
            // Ширина одного кадра
            int frameWidth = spriteTexture.Width / frameCount;
            // Высота анимационной последовательности
            int frameHeight = spriteTexture.Height;
            // Вычленяющий прямоугольник Rectangle(x, y, width, height)
            Rectangle rect = new Rectangle(frameWidth * frame, 0,
                frameWidth, frameHeight);
            // Рисуем кадр
            spriteBatch.Draw(spriteTexture, spritePosition, rect, Color.White);
        }        
        
        // Загрузка спрайта в игру
        public void Load(ContentManager content, String stringTexture)
        {
            spriteTexture = content.Load<Texture2D>(stringTexture);
        }
    
        // Рисование спрайта
        public void DrawSprite(SpriteBatch spriteBatch)
        {
            spriteBatch.Draw(spriteTexture, spritePosition, Color.White);
        }
    }
}
